@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.037';
+$VERSION = '0.041';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -642,17 +642,22 @@ sub wei
             unless ( !keys %{ $res_ref } and ( $ordist > 0 ) and ( $ordist ne "" ) ) ######## IMPROVE THIS SO AS TO ALLOW VERY DIFFERENT NUMBERS OF LEVELS FOR EACH FACTOR
             { #say $tee " SO I AM IN. ";
 
-              my @sorteds;
               my $benchmark;
-              if ( $nfilter )
+              if ( $nfilter ne "" )
               {
-                @sorteds = sort { $b <=> $a } @{ $bank{$trio}{strengths} };
-                $benchmark = $sorteds[$nfilter-1];
+                my @sorteds = sort { $b <=> $a } @{ $bank{$trio}{strengths} };
+                if ( scalar( @sorteds ) > $nfilter )
+                {
+                  $benchmark = $sorteds[$nfilter-1];
+                }
+                else
+                {
+                  $benchmark = 0;
+                }
               }
 
-              if ( ( $strength > $benchmark ) or ( not( $nfilter ) ) )
+              if ( ( $strength > $benchmark ) or ( $nfilter eq "" ) )
               {
-
                 my $count = 0;
                 foreach my $d10 ( @da1 )
                 { #say $tee "WORKING \$d10: " . dump( $d10 );
